@@ -3,18 +3,25 @@
  * Vacation_AliasDriver:: defines an API for implementing vacation backends
  * for the vacation module.
  *
- * $Horde: vacation/lib/AliasDriver.php,v 1.8.2.2 2007/01/02 13:55:21 jan Exp $
+ * $Horde: vacation/lib/AliasDriver.php,v 1.8.2.4 2009/01/06 15:28:06 jan Exp $
  *
- * Copyright 2004-2007 Cronosys, LLC <http://www.cronosys.com/>
+ * Copyright 2004-2009 The Horde Project (http://www.horde.org/)
  *
  * See the enclosed file LICENSE for license information (BSD). If you
  * did not receive this file, see http://www.horde.org/licenses/bsdl.php.
  *
- * @author  Jason M. Felice <jfelice@cronosys.com>
+ * @author  Jason M. Felice <jason.m.felice@gmail.com>
  * @package Vacation
  */
 class Vacation_AliasDriver {
 
+    /**
+     * The current user name.
+     *
+     * @var string
+     */
+    var $_user;
+
     /**
      * Hash containing configuration data.
      *
@@ -25,10 +32,12 @@ class Vacation_AliasDriver {
     /**
      * Constructor
      *
+     * @param string $user   A user name.
      * @param array $params  Configuration parameters for the backend.
      */
-    function Vacation_AliasDriver($params = array())
+    function Vacation_AliasDriver($user, $params = array())
     {
+        $this->_user = $user;
         $this->_params = $params;
     }
 
@@ -49,10 +58,9 @@ class Vacation_AliasDriver {
      * Here we find all aliases which have only the specified user on the
      * right-hand-side (if there are more, it is assumed to be a list).
      *
-     * @param string $name      The name of the user.
-     * @return mixed An array of the aliases, or PEAR_Error on failure.
+     * @return mixed  An array of the aliases, or PEAR_Error on failure.
      */
-    function getAliasesForUser($name)
+    function getAliasesForUser()
     {
         $aliases = $this->getAliases();
         if (is_a($aliases, 'PEAR_Error')) {
@@ -61,7 +69,7 @@ class Vacation_AliasDriver {
 
         $result = array();
         foreach ($aliases as $src => $targets) {
-            if (count($targets) == 1 && $targets[0] == $name) {
+            if (count($targets) == 1 && $targets[0] == $this->_user) {
                 $result[] = $src;
             }
         }
@@ -70,8 +78,9 @@ class Vacation_AliasDriver {
     }
 
     /**
-     * Create a concrete Vacation_AliasDriver:: instance
+     * Creates a concrete Vacation_AliasDriver:: instance.
      *
+     * @param string $user    A user name.
      * @param string $driver  The type of concrete Vacation_AliasDriver
      *                        subclass to return.
      * @param array $params   A hash containing any additional configuration or
@@ -80,7 +89,7 @@ class Vacation_AliasDriver {
      * @return mixed  The newly created concrete Vacation_AliasDriver instance,
      *                or false on error.
      */
-    function &factory($driver = null, $params = null)
+    function factory($user, $driver = null, $params = null)
     {
         if (is_null($driver)) {
             $driver = $GLOBALS['conf']['aliases']['driver'];
@@ -95,7 +104,7 @@ class Vacation_AliasDriver {
         require_once dirname(__FILE__) . '/AliasDriver/' . $driver . '.php';
         $class = 'Vacation_AliasDriver_' . $driver;
         if (class_exists($class)) {
-            $alias = &new $class($params);
+            $alias = new $class($user, $params);
         } else {
             $alias = false;
         }
@@ -103,46 +112,4 @@ class Vacation_AliasDriver {
         return $alias;
     }
 
-    /**
-     * Get a concrete Vacation_AliasDriver instance.
-     *
-     * This method will only create a new instance if no Vacation_AliasDriver::
-     * instance with the same parameters currently exists.
-     *
-     * This should be used if multiple storage sources are required.
-     *
-     * This method must be invoked as: $var = &Vacation_Driver::singleton()
-     *
-     * @param string $driver  The type of concrete Vacation_AliasDriver
-     *                        subclass to return.
-     * @param array $params   A hash containing any additional configuration or
-     *                        connection parameters a subclass might need.
-     *
-     * @return mixed  The created concrete Vacation_AliasDriver instance, or
-     *                false on error.
-     */
-    function &singleton($driver = null, $params = null)
-    {
-        static $instances;
-
-        if (is_null($driver)) {
-            $driver = $GLOBALS['conf']['aliases']['driver'];
-        }
-
-        if (is_null($params)) {
-            $params = Horde::getDriverConfig('aliases', $driver);
-        }
-
-        if (!isset($instances)) {
-            $instances = array();
-        }
-
-        $signature = serialize(array($driver, $params));
-        if (!isset($instances[$signature])) {
-            $instances[$signature] = &Vacation_AliasDriver::factory($driver, $params);
-        }
-
-        return $instances[$signature];
-    }
-
 }
