@@ -1,16 +1,16 @@
 <?php
 /**
- * Vacation_Driver:: defines an API for implementing vacation backends for the
+ * Vacation_AliasDriver:: defines an API for implementing vacation backends for the
  * vacation module.
  *
- * $Horde: vacation/lib/AliasDriver/ftp.php,v 1.5.2.1 2007/01/02 13:55:21 jan Exp $
+ * $Horde: vacation/lib/AliasDriver/ftp.php,v 1.5.2.4 2009/01/29 15:48:04 chuck Exp $
  *
- * Copyright 2004-2007 Cronosys, LLC <http://www.cronosys.com/>
+ * Copyright 2004-2009 The Horde Project (http://www.horde.org/)
  *
  * See the enclosed file LICENSE for license information (ASL). If you
  * did not receive this file, see http://www.horde.org/licenses/asl.php.
  *
- * @author  Jason M. Felice <jfelice@cronosys.com>
+ * @author  Jason M. Felice <jason.m.felice@gmail.com>
  * @package Vacation
  */
 class Vacation_AliasDriver_ftp extends Vacation_AliasDriver {
@@ -20,8 +20,9 @@ class Vacation_AliasDriver_ftp extends Vacation_AliasDriver {
         require_once 'VFS.php';
 
         $params = array('hostspec' => $this->_params['host'],
-                        'port' => $this->_params['port'],
-                        'pasv' => $this->_params['pasv'],
+                        'port'     => $this->_params['port'],
+                        'pasv'     => $this->_params['pasv'],
+                        'ssl'      => $this->_params['ssl'],
                         'username' => $this->_params['username'],
                         'password' => $this->_params['password']);
         $vfs = &VFS::singleton('ftp', $params);
@@ -51,7 +52,7 @@ class Vacation_AliasDriver_ftp extends Vacation_AliasDriver {
         for ($i = 0; $i < count($matches); $i++) {
             $key = $matches[$i][1];
             if (preg_match('/^(.*)@(.*)$/', $key, $kmatches)) {
-                if (!in_array(strtolower($kmatches[2]),
+                if (!in_array(String::lower($kmatches[2]),
                               $this->_params['mydomains'])) {
                     continue;
                 }
@@ -60,7 +61,7 @@ class Vacation_AliasDriver_ftp extends Vacation_AliasDriver {
             $values = preg_split('|\s*,\s*|', $matches[$i][2]);
             foreach ($values as $value) {
                 if (preg_match('/^(.*)@(.*)$/', $value, $vmatches)) {
-                    if (!in_array(strtolower($vmatches[2]),
+                    if (!in_array(String::lower($vmatches[2]),
                                   $this->_params['mydomains'])) {
                         continue;
                     }
