@@ -5,9 +5,9 @@
  * This file brings in all of the dependencies that every Vacation
  * script will need, and sets up objects that all scripts use.
  *
- * $Horde: vacation/lib/base.php,v 1.35.2.3 2007/01/02 13:55:21 jan Exp $
+ * $Horde: vacation/lib/base.php,v 1.35.2.6 2009/01/06 15:28:06 jan Exp $
  *
- * Copyright 2001-2007 Eric Rostetter <eric.rostetter@physics.utexas.edu>
+ * Copyright 2001-2009 The Horde Project (http://www.horde.org/)
  *
  * See the enclosed file LICENSE for license information (BSD). If you
  * did not receive this file, see http://www.horde.org/licenses/bsdl.php.
@@ -42,11 +42,3 @@ $notification->attach('status');
 
 // Help.
 require_once 'Horde/Help.php';
-
-/**
- * Default strings for vacation messages, just to have them in the source for
- * localization reasons.
- */
-_("On vacation message");
-_("I'm on vacation and will not be reading my mail for a while.");
-_("Your mail will be dealt with when I return.");
